@@ -4,12 +4,19 @@ module Unparser
   class Emitter
     # Emitter for flip flops
     class FlipFlop < self
-      include Unterminated
-
-      MAP = IceNine.deep_freeze(
+      MAP = {
         iflipflop: '..',
         eflipflop: '...'
-      ).freeze
+      }.freeze
+
+      SYMBOLS = {
+        eflipflop: :tDOT3,
+        iflipflop: :tDOT2
+      }.freeze
+
+      def symbol_name
+        true
+      end
 
       handle(*MAP.keys)
 
@@ -17,16 +24,15 @@ module Unparser
 
     private
 
-      # Perform dispatch
-      #
-      # @return [undefined]
-      #
-      # @api private
-      #
       def dispatch
-        visit(left)
+        visit(left) if left
         write(MAP.fetch(node.type))
-        visit(right)
+
+        if right
+          visit(right)
+        else
+          write(';')
+        end
       end
     end # FlipFLop
   end # Emitter
