@@ -4,18 +4,10 @@ module Unparser
   class Emitter
     # Emitter for lambda nodes
     class Lambda < self
-      include Terminated
-
       handle :lambda
 
     private
 
-      # Perform dispatch
-      #
-      # @return [undefined]
-      #
-      # @api private
-      #
       def dispatch
         write('->')
       end
