@@ -4,46 +4,40 @@ module Unparser
   class Emitter
     # Emitter for splats
     class KwSplat < self
-      include Terminated
-
       handle :kwsplat
 
       children :subject
 
     private
 
-      # Perform dispatch
-      #
-      # @return [undefined]
-      #
-      # @api private
-      #
       def dispatch
-        write(T_SPLAT, T_SPLAT)
+        write('**')
         visit(subject)
       end
     end
 
     # Emitter for splats
     class Splat < self
-      include Terminated
-
       handle :splat
 
       children :subject
 
+      def emit_mlhs
+        write('*')
+        subject_emitter.emit_mlhs if subject
+      end
+
     private
 
-      # Perform dispatch
-      #
-      # @return [undefined]
-      #
-      # @api private
-      #
       def dispatch
-        write(T_SPLAT)
-        visit(subject) if subject
+        write('*')
+        subject_emitter.write_to_buffer
       end
+
+      def subject_emitter
+        emitter(subject)
+      end
+      memoize :subject_emitter
     end
   end
 end # Unparser
