@@ -4,20 +4,12 @@ module Unparser
   class Emitter
     # Emitter for undef nodes
     class Undef < self
-      include Unterminated
-
       handle :undef
 
     private
 
-      # Perform dispatch
-      #
-      # @return [undefined]
-      #
-      # @api private
-      #
       def dispatch
-        write(K_UNDEF, WS)
+        write('undef ')
         delimited(children)
       end
 
